==> billogram-foundation-3.13.10.tgz: package/modules/components/component/createComponent.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import { connect } from 'react-redux';
import invariant from 'invariant';

import isNullOrEmpty from '../../utils/isNullOrEmpty';

import mount from './redux/mount';
import unmount from './redux/unmount';


export default (registry) => (Component, {
    initialComponentState,
    initialize = null,
    reducers = null,
    root
} = {}) => {

    invariant(Component !== undefined, 'Missing Component');
    invariant(!isNullOrEmpty(root), 'Missing root.');

    const Container = React.createClass({

        displayName: `Component(${Component.displayName})`,

        mixins: [PureRenderMixin],

        propTypes: {
            isMounted: PropTypes.bool.isRequired,
            onMount: PropTypes.func.isRequired,
            onUnmount: PropTypes.func.isRequired,
            // ---
            component: PropTypes.object
        },

        componentDidMount() {
            this.props.onMount();
        },

        componentWillUnmount() {
            this.props.onUnmount();
        },

        render() {
            const {
                isMounted,
                onMount,        // eslint-disable-line no-unused-vars
                onUnmount,      // eslint-disable-line no-unused-vars
                component,
                ...rest
            } = this.props;

            if (!isMounted) {
                return null;
            }

            return (
                <Component
                    { ...rest }
                    component={ component }
                    root={ root } />
            );
        }

    });

    const mapStateToProps = (state) => {
        const component = state.components[root];
        const isMounted = !!state.components.meta.mounted[root];

        return {
            component,
            isMounted
        };
    };

    const mapDispatchToProps = (dispatch, props) => {
        return {
            onMount: () => {
                if (reducers !== null) {
                    registry.add(root, reducers);
                }

                dispatch(mount({ initialComponentState, root }));

                if (initialize !== null) {
                    dispatch(initialize({ props, root }));
                }
            },
            onUnmount: () => {
                dispatch(unmount({ root }));

                if (reducers !== null) {
                    registry.remove(root);
                }
            }
        };
    };

    return connect(mapStateToProps, mapDispatchToProps)(Container);
};

==> billogram-foundation-4.8.4.tgz: package/modules/components/component/createComponent.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import { connect } from 'react-redux';
import invariant from 'invariant';

import isNullOrEmpty from '../../utils/isNullOrEmpty';

import mount from './redux/mount';
import unmount from './redux/unmount';


export default (registry) => (Component, {
    initialComponentState,
    initialize = null,
    reducers = null,
    root,
} = {}) => {

    invariant(Component !== undefined, 'Missing Component');
    invariant(!isNullOrEmpty(root), 'Missing root.');

    const Container = React.createClass({

        displayName: `Component(${Component.displayName})`,

        mixins: [PureRenderMixin],

        propTypes: {
            isMounted: PropTypes.bool.isRequired,
            onMount: PropTypes.func.isRequired,
            onUnmount: PropTypes.func.isRequired,
            // ---
            component: PropTypes.object,
        },

        componentDidMount() {
            this.props.onMount();
        },

        componentWillUnmount() {
            this.props.onUnmount();
        },

        render() {
            const {
                isMounted,
                onMount,        // eslint-disable-line no-unused-vars
                onUnmount,      // eslint-disable-line no-unused-vars
                component,
                ...rest
            } = this.props;

            if (!isMounted) {
                return null;
            }

            return (
                <Component
                    { ...rest }
                    component={ component }
                    root={ root } />
            );
        },

    });

    const mapStateToProps = (state) => {
        const component = state.components[root];
        const isMounted = !!state.components.meta.mounted[root];

        return {
            component,
            isMounted,
        };
    };

    const mapDispatchToProps = (dispatch, props) => {
        return {
            onMount: () => {
                if (reducers !== null) {
                    registry.add(root, reducers);
                }

                dispatch(mount({ initialComponentState, root }));

                if (initialize !== null) {
                    dispatch(initialize({ props, root }));
                }
            },
            onUnmount: () => {
                dispatch(unmount({ root }));

                if (reducers !== null) {
                    registry.remove(root);
                }
            },
        };
    };

    return connect(mapStateToProps, mapDispatchToProps)(Container);
};
